// Rendere ein Objekt nicht mit seiner eigtl. Farbe,
// sondern mit dem Tiefenwert als Farbe.
// Das Resultat heisst "depth map".
// 
// Annahme: das Objekt hat als "Mittelpunkt" den Koordinatenursprung
// (des Objektkoordinatensystems)
//
// GZ 2011, TU Clausthal, http://zach.in.tu-clausthal.de/cg_in_schule/


// Mit diesen beiden Werten kann man aus dem ShaderMaker heraus
// die Z-Werte noch ein wenig beeinflussen, so dass der Wertebereich
// schoen das volle Intervall [0,1] ausnutzt.
// Fuer den Torus eignen sich z_scale = 0.3 und z_shift = 0.7 recht gut.
uniform float z_scale;
uniform float z_shift;

void main()
{
	// Berechnung der Vertex-Position im Kamerakoord.system
	vec4 posInCS = gl_ModelViewMatrix * gl_Vertex;

	// Transformiere den Obj.koord.ursprung ins Kamerakoord.system
	vec4 centerInCS = gl_ModelViewMatrix * vec4(0, 0, 0, 1);

	// Berechne den Laengenunterschied
	float dist = (length(posInCS) - length(centerInCS)) * z_scale + z_shift;

	// Verwende den Z-Wert als Farbe
	gl_FrontColor = vec4( dist, dist, dist, 1 );
	// etwas bunter ist folgendes
	gl_FrontColor = vec4( 1.0-dist, dist, dist, 1 );

	// Diese Zeile muss fast immer kommen, so oder in aehnlicher Form,
	// damit der Eckpunkt ins Kamerakoordinatensystem umgerechnet wird
	// (z.B. fuer die Rotation der Szene durch den virtuellen Trackball)
	gl_Position = gl_ModelViewProjectionMatrix * gl_Vertex;
}
