// Per-Pixel Phong lighting
//
// GZ 2011, TU Clausthal, http://zach.in.tu-clausthal.de/cg_in_schule/


// Vertex-Normale vom Rasterizer
varying vec3 normal;
// Vertex-Position im Kamera System, vom Rasterizer
varying vec3 pos;

void main()
{	
	// Ambiente Farbe
	vec4 ambient = 1.0 * gl_LightSource[0].ambient;
	
	// Berechnung des diffusen Anteils
	vec3 lightDir = normalize( vec3( gl_LightSource[0].position ) - pos );
	float intensityDiffuse = dot( normal, lightDir );

	// Setzen der diffusen Farbe
	vec4 diffuse = vec4( 0.0 );
	if ( intensityDiffuse > 0.0 )
		diffuse = gl_LightSource[0].diffuse * gl_Color * intensityDiffuse;
		
	// Berechnung des spiegelnden Anteils
	vec3 rVector = normalize( 2.0 * normal * dot(normal, lightDir) - lightDir );
	float intensitySpecular = dot( rVector, normalize(-pos) );
	
	// Setzen der spiegelnden Farbe
	float shininess = 20.0;						// "Spiegel"-Faktor
	vec4 specular = vec4( 0.0 );
	if ( intensitySpecular > 0.0 )
		specular = gl_LightSource[0].specular * pow( intensitySpecular, shininess );

	// Setzen der Farbe
	gl_FragColor = ambient + diffuse + specular;
} 
