// Ein Shader, der sog. "Toon Shading" macht, d.h., die Objekte so
// darstellt, dass sie aehnlich wie in einem Cartoon aussehen (hence the name)
//
// ACHTUNG: dieser Shader funktioniert nur dann richtig, wenn w=0 in der Position
// der Lichtquelle, da er eine "directional light source" annimt!
// (Der Shader toon2,{vert,frag} ist generisch programmiert, so dass er mit
// positional als auch directional light source zurecht kommt.)
//
// GZ 2011, TU Clausthal, http://zach.in.tu-clausthal.de/cg_in_schule/


// Mit dieser uniform-Variable koennen wir aus dem Shader Editor die Grundfarbe
// des Toon-Shadings setzen (wir ignorieren naemlich die Objekt-/Vertex-Farbe, die von 
// der Applikation hereingereicht wird)
uniform vec3 color;

// Kommt vom Rasterizer bzw. Vertex-Shader
varying vec3 normal;

void main()
{
	// Berechne Vektor zur Lichtquelle (wir nehmen an, dass Lightsource[0] = Richtungslichtquelle)
	vec3 l = normalize( gl_LightSource[0].position.xyz );

	// Normiere Normale (kann durch Rasterizer Laenge ungleich 1 bekommen)
	vec3 n = normalize(normal);

	// Setze Helligkeit fuer dieses Pixel abhaengig vom Winkel zwischen
	// Lichtvektor und Normale, ...
	float intensity = dot( l, n );

	float c;
	if (intensity > 0.95)			// ... und zwar in diskreten Levels
		c = 1.0;
	else if (intensity > 0.7)
		c = 0.7;
	else if (intensity > 0.5)
		c = 0.5;
	else
		c = 0.3;

	gl_FragColor = c * vec4( color, 1.0);
}
