// Ein Shader, der sog. "Toon Shading" macht, d.h., die Objekte so
// darstellt, dass sie aehnlich wie in einem Cartoon aussehen (hence the name)
//
// Dieser Shader kommt auch mit positional light sources zurecht, daher
// der etwas hoehere Aufwand.
//
// GZ 2011, TU Clausthal, http://zach.in.tu-clausthal.de/cg_in_schule/


// Mit dieser uniform-Variable koennen wir aus dem Shader Editor die Grundfarbe
// des Toon-Shadings setzen (wir ignorieren naemlich die Objekt-/Vertex-Farbe, die von 
// der Applikation heringereicht wird)
uniform vec3 color;

// Kommt vom Rasterizer bzw. Vertex-Shader
varying vec3 normal;
varying vec3 surf_pos;

void main()
{
	// Berechne Vektor von unserer Position in Weltkoord. zur Lichtquelle
	// Der folgende Ausdruck ist (im Prinzip) aequivalent zu 
	// normalize( gl_LightSource[0].position.xyz/gl_LightSource[0].position.w - position ),
	// funktioniert aber auch dann, wenn Lichtquelle = Richtungsvektor (oder position)
	vec3 l = normalize( gl_LightSource[0].position.xyz - surf_pos * gl_LightSource[0].position.w  );

	// Normiere Normale (kann durch Rasterizer Laenge ungleich 1 bekommen)
	vec3 n = normalize( normal );

	// Setze Helligkeit fuer dieses Pixel abhaengig vom Winkel zwischen
	// Lichtvektor und Normale ...
	float intensity = dot( l, n );

	vec4 c;
	if (intensity > 0.95)			// ... und zwar in diskreten Levels
		c = vec4( color,1.0 );
	else if (intensity > 0.7)
		c = vec4( 0.7*color, 1.0 );
	else if (intensity > 0.4)
		c = vec4( 0.5*color, 1.0 );
	else
		c = vec4( 0.3*color, 1.0 );

	gl_FragColor = c;
}

